# [bitwardenrs](https://gitea.rknet.org/docker/bitwarden_rs)

[![Build Status](https://img.shields.io/drone/build/docker/bitwarden_rs?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/docker/bitwarden_rs)
[![Docker Hub](https://img.shields.io/badge/docker-latest-blue.svg?logo=docker&logoColor=white)](https://hub.docker.com/r/xoxys/bitwardenrs)
[![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/docker/bitwarden_rs/src/branch/master/LICENSE)

This is a custom Docker image for [bitwarden_rs](https://github.com/dani-garcia/bitwarden_rs). Bitwarden_rs is a Bitwarden server API implementation written in Rust compatible with upstream Bitwarden clients, perfect for self-hosted deployment where running the official resource-heavy service might not be ideal.

> __WARNING__: While bitwarden_rs does not allow to compile binaries with multi DB providers, this build will only work with a PostgreSQL database backend.

## Usage

### Docker Compose

Compatible with docker-compose v3 schemas.

```Yaml
---
version: '3'

services:
  postgres:
    container_name: bitwardenrs_postgres
    image: postgres
    environment:
      POSTGRES_DB: bitwarden
      POSTGRES_PASSWORD: pass
      POSTGRES_USER: user

  bitwardenrs:
    container_name: bitwardenrs
    image: xoxys/bitwardenrs:latest
    depends_on:
      - postgres
    ports:
      - "80:8080"
    volumes:
      - data:/app/data
    environment:
      BITWARDENRS_WAIT_FOR_HOST: bitwardenrs_postgres
      BITWARDENRS_WAIT_FOR_PORT: 5432
      BITWARDENRS_DATABASE_URL: postgresql://user:pass@bitwardenrs_postgres:5432/bitwarden
      BITWARDENRS_ADMIN_TOKEN: test

volumes:
  data:
    driver: local
```

## Configuration

```Shell
BITWARDENRS_DATABASE_URL=
# Wait for database host. If you don't set a Host and Port
# Bitwarden will start immediately.
BITWARDENRS_WAIT_FOR_HOST=
BITWARDENRS_WAIT_FOR_PORT=
BITWARDENRS_WAIT_FOR_TIMEOUT=15

BITWARDENRS_TEMPLATES_FOLDER=
BITWARDENRS_RELOAD_TEMPLATES=False

BITWARDENRS_IP_HEADER=X-Client-IP

BITWARDENRS_ICON_CACHE_TTL=2592000
BITWARDENRS_ICON_CACHE_NEGTTL=259200

BITWARDENRS_WEB_VAULT_ENABLED=True
BITWARDENRS_WEBSOCKET_ENABLED=False

BITWARDENRS_EXTENDED_LOGGING=True
BITWARDENRS_LOG_LEVEL=Info

BITWARDENRS_DISABLE_ICON_DOWNLOAD=False
BITWARDENRS_ICON_DOWNLOAD_TIMEOUT=10
BITWARDENRS_ICON_BLACKLIST_REGEXL=
BITWARDENRS_ICON_BLACKLIST_NON_GLOBAL_IPS=True

BITWARDENRS_DISABLE_2FA_REMEMBER=False
BITWARDENRS_SIGNUPS_ALLOWED=True
BITWARDENRS_SIGNUPS_VERIFY=False
BITWARDENRS_SIGNUPS_VERIFY_RESEND_TIME=3600
BITWARDENRS_SIGNUPS_VERIFY_RESEND_LIMIT=6
BITWARDENRS_SIGNUPS_DOMAINS_WHITELIST=

BITWARDENRS_INVITATIONS_ALLOWED=True

# Set an indicidual admin token to enable the admin UI
BITWARDENRS_ADMIN_TOKEN=

BITWARDENRS_PASSWORD_ITERATIONS=100000
BITWARDENRS_SHOW_PASSWORD_HINT=True
BITWARDENRS_DOMAIN=http://localhost/

BITWARDENRS_AUTHENTICATOR_DISABLE_TIME_DRIFT=False

# If you dont set a smtp host, all other smpt settings will be ignored
BITWARDENRS_SMTP_HOST=
BITWARDENRS_SMTP_FROM=
BITWARDENRS_SMTP_FROM_NAME=Bitwarden_RS
BITWARDENRS_SMTP_PORT=587
BITWARDENRS_SMTP_SSL=True
BITWARDENRS_SMTP_USERNAME=
BITWARDENRS_SMTP_PASSWORD=
BITWARDENRS_SMTP_AUTH_MECHANISM=Plain
BITWARDENRS_SMTP_TIMEOUT=15
```

### License

This project is licensed under the MIT License - see the [LICENSE](https://gitea.rknet.org/docker/bitwarden_rs/src/branch/master/LICENSE) file for details.

### Maintainers and Contributors

[Robert Kaussow](https://gitea.rknet.org/xoxys)
